function GenerateFigure(figidx,exportFlag)
% GENERATEFIGURE   Generates plot from the paper
%
%    GENERATEFIGURE(FIXIDX,EXPORTFLAG) generates figure FIXIDX from the
%    paper, if it exists. The optional EXPORTFLAG parameter can be set to
%    export the plot to a PDF file. When FIXIDX = [], all figures are
%    generated. Valid values for FIXIDX are:
%
%    1   - L11 and L12 breakdown curves for standard 20 x 60 matrix for
%          three different numbers of observation vectors. Averaged over
%          1,000 trials.
%
%    2   - Recovery using L12 of the counter example where L11 fails using
%          a range of weighting vectors.
%
%    4   - Theoretical and experimental recovery using Boosted-L1 for varying
%          numbers of measurements and sparsity levels, averaged over 1,000
%          problem instances.
%
%    6   - Projected performance of ReMBo for three problems with different
%          sparsity levels and L1 recovery rates.
%
%    7   - Plots that show how the number of unique orthants increases as a
%          function of weight vectors tried, and the way this affects the
%          recovery rate of ReMBo-L1.
%
%    8   - Number of unique orthants as a function of iterations for different
%          matrix types X.
%
%    9   - Distribution of orthant counts and comparison between experimental
%          and modelled ReMBo-L1 performance.
%
%    101 - L1 breakdown curve for standard 20 x 80 matrix based on 10,000
%          trials. (Does not appear in the paper.)

%    Copyright 2009, Ewout van den Berg and Michael P. Friedlander
%    This file is part of the code accompanying the paper: Joint-sparse
%    recovery from multiple measurements, submitted April 2009.

% Check parameters
if nargin < 1
   error('First parameter should be an integer figure index.');
end
if nargin < 2
   exportFlag = 0;
end

% Generate all figures if figidx is empty
if isempty(figidx)
   figidx = [1,2,4,6,7,8,9];
   for i=1:length(figidx)
      GenerateFigure(figidx(i),exportFlag);
   end

   return;
end

% Generate specified figure
switch figidx
case 1
   ExecuteScript('L12','FigBreakdownL12Plot(exportFlag);');

case 2
   ExecuteScript('Triangle','TestTriangle(5,exportFlag);');
   fprintf('Press <return> to continue . . .\n');
   pause;
   ExecuteScript('Triangle','TestTriangle(10,exportFlag);');
   fprintf('Press <return> to continue . . .\n');
   pause;
   ExecuteScript('Triangle','TestTriangle2(5,exportFlag);');
   fprintf('Press <return> to continue . . .\n');
   pause;
   ExecuteScript('Triangle','TestTriangle2(7,exportFlag);');
   fprintf('Press <return> to continue . . .\n');
   pause;
   ExecuteScript('Triangle','TestTriangle2(10,exportFlag);');
   fprintf('Press <return> to continue . . .\n');
   pause;
   ExecuteScript('Triangle','TestTriangle3(10,exportFlag);');
   fprintf('Press <return> to continue . . .\n');

case 4
   ExecuteScript('BoostedL1','FigBoostedL1(exportFlag);');

case 6
   ExecuteScript('ReMBo','FigReMBoBound(exportFlag);');

case 7
   ExecuteScript('Orthants','FigApproachPairsC10_5(exportFlag);');

case 8
   ExecuteScript('Orthants','FigApproachC5_9(exportFlag);');
   fprintf('Press <return> to continue . . .\n');
   pause;
   ExecuteScript('Orthants','FigApproachCx_10(exportFlag);');

case 9
   ExecuteScript('Orthants','FigFiniteCdnPairs(exportFlag);');
   fprintf('Press <return> to continue . . .\n');
   pause;
   ExecuteScript('ReMBo','FigReMBo(3,exportFlag);');
   fprintf('Press <return> to continue . . .\n');
   pause;
   ExecuteScript('ReMBo','FigReMBo(4,exportFlag);');

case 101 % Does not appear in paper
   ExecuteScript('L1','RecoveryL1(20,80,10000,exportFlag);');

otherwise
   fprintf('No code available to generate Figure %d\n',figidx);
end


% Execude script in its local directory
function ExecuteScript(workdir,command)

   p = pwd;
   cd([mfilepath(mfilename('fullpath')),workdir]);
   try
      eval(command);
      cd(p);
   catch exception
      cd(p);
      rethrow(exception);
   end
end

end

