function RecoveryL1(m,n,trials,exportFlag)
% RECOVERYL1   Computes breakdown curve for a standard m-by-n matrix
%
%    RECOVERYL1(M,N,TRIALS,EXPORTFLAG)  computes the breakdown curve
%    for a standard M-by-N random matrix generated with the
%    GENERATEMATRIXA function. All sparsity levels from 1 to M are
%    tried on random support and the average recovery rate is computed
%    over TRIALS simulations. Intermediate results and the script can
%    be interrupted and restarted at any time and restarted with the
%    loss of at most M basis pursuit solves. When the number of trials
%    in the stored data exceeds that given by TRIALS, the number of
%    trials in the data is used. When the EXPORTFLAG parameters is set
%    the plot will be exported to a PDF file.

%    Copyright 2009, Ewout van den Berg and Michael P. Friedlander
%    This file is part of the code accompanying the paper: Joint-sparse
%    recovery from multiple measurements, submitted April 2009.

% Load the standard A because recovery properties are matrix specific
[A,staten] = GenerateMatrixA(m,n); state = 0;

% Initialize trial count
if nargin > 2
   jMax = trials;
else
   jMax = 10000;
end

% Check arguments
if nargin < 4, exportFlag = 0; end

% Construct filename
prefix   = mfilepath(mfilename('fullpath'));
filename = sprintf('%sRecoveryL1_%d_%d.mat',prefix,m,n);

if exist(filename);
   s = load(filename);
   jStart  = s.j+1;
   success = s.success;
   state   = s.state;
   staten  = s.staten;
   if s.j > jMax, jMax = s.j; end;
else
   success = zeros(1,20);
   jStart  = 1;
end

% Set random number generators
rand('state',state); randn('state',staten);

% Trials
for j=jStart:jMax
   disp([j,jMax]);
   for i=1:20
      p  = randperm(80);
      x0 = zeros(80,1); x0(p(1:i)) = sign(randn(i,1));
      b  = A*x0;
      [x,info] = cvx_bp(A,b);

      if norm(x-x0,inf) < 1e-5
         success(i) = success(i) + 1;
      end
   end

   state  = rand('state');
   staten = randn('state');
   save('filename','success','j','state','staten');
end


h = plot(1:20,100 * (success / jMax));
set(h,'LineWidth',2);
set(gca,'Fontsize',16);
xlabel('Sparsity'); ylabel('Recovery rate (%)');

% Export figure to PDF file
if exportFlag
   ExportFigurePDF(prefix, sprintf('RecoveryL1_%d_%d.pdf',m,n));
end

