function FigApproachC5_9(exportFlag)
% FIGAPPROACHC5_9   Plots unique orthant count versus iteration for 9x5 matrix
%
%    FIGAPPROACHC5_9(EXPORTFLAG) generates two different 9-by-5 matrices X. The
%    first one with i.i.d. normal entries and columns normalized to unit norm.
%    The second matrix is generated by adding perturbations to a single vectors
%    with i.i.d. normal entries, also scaled to unit norm. Based on each X we
%    generate ten million weight vectors w and determine at which iterations a
%    new sign pattern sign(Xw), excluding negation, is encountered. The number
%    of unique patterns is then plotted against the number of iterations for
%    both matrices.

%    Copyright 2009, Ewout van den Berg and Michael P. Friedlander
%    This file is part of the code accompanying the paper: Joint-sparse
%    recovery from multiple measurements, submitted April 2009.

% Check arguments
if nargin < 1, exportFlag = 0; end

% Get filename prefix
prefix = mfilepath(mfilename('fullpath'));

randn('state',2);
n = 10000000; % Ten million

% Create 9-by-5 matrix with unit norm columns
X = randn(9,5);
X = X * spdiags(1./sqrt(sum(X.^2)'),0,5,5);
mcA = max(max(abs(X'*X - eye(5,5))));
anA = abs(X'*X - eye(5,5)); anA = sort(anA(:)); anA = mean(acos(anA(6:end))*180/pi);

filename = sprintf('%sFigApproachC5_9a.mat',prefix);
if ~exist('FigApproachC5_9a.mat')
   [idxA,countA] = SampleCdnBasicPairs(X,n);
   save(filename,'idxA','countA');
else
   load(filename);
end

% Create 9-by-5 matrix based on perturbations of a single vector
X = repmat(randn(9,1),1,5) + 0.1 * randn(9,5);
X = X * spdiags(1./sqrt(sum(X.^2)'),0,5,5);
mcB = max(max(abs(X'*X - eye(5,5))));
anB = abs(X'*X - eye(5,5)); anB = sort(anB(:)); anB = mean(acos(anB(6:end))*180/pi);

filename = sprintf('%sFigApproachC5_9b.mat',prefix);
if ~exist('FigApproachC5_9b.mat')
   [idxB,countB] = SampleCdnBasicPairs(X,n);
   save(filename,'idxB','countB');
else
   load(filename);
end

% Plot results
figure(1); clf; gca; hold on;
idxExtendedA = [idxA,n]; countExtendedA = [1:length(idxA),length(idxA)];
idxExtendedB = [idxB,n]; countExtendedB = [1:length(idxB),length(idxB)];
h = plot(idxExtendedA,countExtendedA,...
         idxExtendedB,countExtendedB);
set(gca,'Fontsize',16,'XScale','log');
set(h,'LineWidth',2); xlim([0,n]); ylim([0,170]);

% Add markers to second plot
idx = getPlotIndex(log10(idxExtendedB),30);
hB  = plot(idxExtendedB(idx),countExtendedB(idx),'.');
set(hB,'Linewidth',2,'Color',get(h(2),'Color'),'Marker','x','MarkerSize',7);

% Add dummy lines for legend
hDummy = plot([1,1;10,10],[-1,-1;-1,-1],'-');
set(hDummy(1),'Linewidth',2,'Color',get(h(1),'Color'));
set(hDummy(2),'Linewidth',2,'Color',get(h(2),'Color'),'Marker','x','MarkerSize',7);

hold off; box on;
legend(hDummy,'Gaussian','Perturbed','Location','SouthEast');
xlabel('Iterations'); ylabel('Unique sign patterns');

if exportFlag
   ExportFigurePDF(prefix,'FigApproachC5_9.pdf');
end

% Display the average angle between columns in the two X matrices
disp('Average angle between columns:');
disp([anA,anB]);


