function FigApproachPairsC10_5(exportFlag)
% FIGAPPROACHPAIRSC10_5   Plots orthant count versus trials approaching C(10,5)
%
%    FIGAPPROACHPAIRSC10_5(EXPORTFLAG) generates up to 10^8 random combinations
%    of 5 vectors in R^10 and counts the number of sign patterns (up to
%    negation) that are thus obtained. This number is plotted against the
%    number of trials in the first figure. The second figure plots the relative
%    frequency with which each sign patterns is reached. The fraction of unique
%    patterns divided by the number of iterations is plotted in the third
%    figure. The fourth figure gives a projected performance for ReMBo-l1 as a
%    function of trials, based on the unique sign pattern count combined with
%    the number of faces of a fixed support in the cross polytope C and its
%    mapping AC.

%    Copyright 2009, Ewout van den Berg and Michael P. Friedlander
%    This file is part of the code accompanying the paper: Joint-sparse
%    recovery from multiple measurements, submitted April 2009.

% Check arguments
if nargin < 1, exportFlag = 0; end

% Get filename prefix
prefix = mfilepath(mfilename('fullpath'));

randn('state',0);
X = randn(10,5);

filename = sprintf('%sFigApproachPairsC10_5.mat',prefix);
if ~exist(filename)
   [idx,count] = SampleCdnBasicPairs(X,100000000);
   save(filename,'idx','count');
else
   load(filename);
end


% ===========================================================================
% Figure 1
% ===========================================================================
figure(1);
h = plot(idx,1:length(idx));
set(gca,'XScale','log'); xlim([0,1e8]);
set(gca,'Fontsize',16);
set(h,'Linewidth',2);
xlabel('Iterations'); ylabel('Unique sign pattern pairs');

if exportFlag
   ExportFigurePDF(prefix,'FigApproachPairsC10_5a.pdf');
end


% ===========================================================================
% Figure 2
% ===========================================================================
figure(2); clf; gca; hold on; h = []; l = {};
cValues = [0.75 0  0;   0 0.75 0;   0 0 1.00];
markers = {'none','x','+'};

for i=0:2
   [A,support,faces] = PresolvedSupportProblem(10,i);
   remboRate = SuccessRateReMBoTheory(sum(faces),length(faces),[1:length(idx),length(idx)]);
   idxExtend = [idx,1e8];
   markerIdx= getPlotIndex(log10(idxExtend),30);
   hMarker  = plot(idxExtend(markerIdx),100*remboRate(markerIdx),'.');
   h(end+1) = plot([idx,1e8],100*remboRate);
   l{end+1} = sprintf('p = %4.2f%%',100*sum(faces)/length(faces));

   set([h(end),hMarker],'Color',cValues(i+1,:),'Linewidth',2);
   set(hMarker,'Marker',markers{i+1},'MarkerSize',7);

   % Override current handle by dummy line with correct color and marker
   h(end) = plot([1,10],[-1,-1],'-');
   set(h(end),'Color',cValues(i+1,:),'Linewidth',2);
   set(h(end),'Marker',markers{i+1},'MarkerSize',7);
end

hold off; box on; xlim([0,1e8]); ylim([0,100]);
set(gca,'XScale','log','Fontsize',16);
xlabel('Iterations'); ylabel('Recovery rate (%)');
legend(h,l{:},'Location','SouthEast');

if exportFlag
   ExportFigurePDF(prefix,'FigApproachPairsC10_5b.pdf');
end


% ===========================================================================
% Figure 3
% ===========================================================================
figure(3);
h = plot(sort(count,'descend')/1e6);
set(gca,'Fontsize',16);
set(h,'Linewidth',2);
ylabel('Instances (% of trials)');
xlabel('Sign pattern index');

if exportFlag
   ExportFigurePDF(prefix,'FigApproachPairsC10_5c.pdf');
end


% ===========================================================================
figure(4);
% ===========================================================================
h = plot(idx,(1:length(idx))./idx);
set(gca,'XScale','Log'); ylim([0,1.05]);
set(gca,'Fontsize',16);
set(h,'Linewidth',2);
xlabel('Iterations'); ylabel('Unique sign pattern pairs per iteration');

if exportFlag
   ExportFigurePDF(prefix,'FigApproachPairsC10_5d.pdf');
end

