function [A,p,success] = PresolvedSupportProblem(r,idx)
% PRESOLVEDSUPPORTPROBLEM   Solves L1 for all sign-patterns on fixed support
%
%    [A,P,SUCCESS] = PRESOLVEDSUPPORTPROBLEM(R,IDX) generates a standard 20x60
%    matrix A, chooses a random support P of size R and solves the basis
%    pursuit problem for all different +/-1 sign patterns on that support. The
%    IDX parameter is used to set the random number generator, and therewith
%    determines the support. The output parameters are matrix A, the support
%    P, and vector SUCCESS indicating the recovery property of each face.
%    Faces are indexed by the value of the binary representation of the sign
%    patterns.

%    Copyright 2009, Ewout van den Berg and Michael P. Friedlander
%    This file is part of the code accompanying the paper: Joint-sparse
%    recovery from multiple measurements, submitted April 2009.

% Choose filename
filename = sprintf('%sPresolvedSupportProblem_r%d_%d.mat',mfilepath(mfilename('fullpath')),r,idx);

if exist(filename)
   load(filename);
else
   % Load matrix A used throughout experiments
   [A,state] = GenerateMatrixA(20,80);
   [m,n] = size(A);
   rand('state',r*3+idx);

   % Select support
   p = randperm(n); p = p(1:r);

   % Initialize success matrix
   success1e5 = zeros(1,power(2,r-1));
   success1e6 = zeros(1,power(2,r-1));
   success1e7 = zeros(1,power(2,r-1));

   base = power(2,r-1);
   for i=1:power(2,r-1)
      fprintf('%3d\n',i);
      x0= zeros(n,1);
      x0(p(1:r)) = 2 * (dec2bin(base + i-1) == '1') - 1;
      b = A*x0;

      % Solve the problem
      cmdCVX = 'cvx_bp(A,b)'; [output,x,info] = evalc(cmdCVX);

      if norm(x-x0,inf) < 1e-5
         success1e5(i) = 1;
      end
      if norm(x-x0,inf) < 1e-6
         success1e6(i) = 1;
      end
      if norm(x-x0,inf) < 1e-7
         success1e7(i) = 1;
      end
   end

   success1e5 = [success1e5, success1e5(end:-1:1)];
   success1e6 = [success1e6, success1e6(end:-1:1)];
   success1e7 = [success1e7, success1e7(end:-1:1)];

   facemap = [success1e5; success1e6; success1e7];

   % Save result
   save(filename,'A','p','facemap');
end

success = facemap(1,:);

