function FigReMBo(t,exportFlag)
% FIGREMBO   Generates performance curves for ReMBo
% 
%    FIGREMBO(T,EXPORTFLAG)  generates ideal recovery curves for ReMBo-L1
%    using empirical result on number of orthants covered, for three problems
%    with different support size. The number of trials is as follows:
%    T = 1 :     10
%        2 :    100
%        3 :  1,000
%        4 : 10,000
%
%    When the EXPORTFLAG parameters is set the plot will be exported to a PDF
%    file.

%    Copyright 2009, Ewout van den Berg and Michael P. Friedlander
%    This file is part of the code accompanying the paper: Joint-sparse
%    recovery from multiple measurements, submitted April 2009.

% Check arguments
if nargin < 2, exportFlag = 0; end

% Get filename prefix
prefix = mfilepath(mfilename('fullpath'));

% Create figure
figure(1); clf; gca; hold on;
h1 = []; h2 = [];

sValues = [8,9,10];
iValues = [4,0, 2];
tValues = [t,t, t];
cValues = [0.75 0  0;   0 0.75 0;   0 0 1.00];
markers = {'none','x','+'};

trials = [10,100,1000,10000]; % Trial values

for i=1:length(sValues)
   instances = 1000;
   s         = sValues(i); % Row sparsity
   idx       = iValues(i); % Support number for given row sparsity
   r         = 20;         % Maximum number of observations

   filename = sprintf('%sFigReMBo_s%d_%d_%d.mat',prefix,s,idx,trials(tValues(i)));
   if exist(filename)
      load(filename);
   else
      [success,p] = ReMBo_Presolved(s,idx,instances,trials(tValues(i)),r);
      save(filename,'success','p');
   end

   % Generate empirical ReMBo curve
   [A,q,faces] = PresolvedSupportProblem(s,idx);

   remboEmpr = zeros(1,r);
   for k=1:r
      c = FiniteCdnPairs(k,s);
      remboEmpr(k) = mean(SuccessRateReMBoTheory(sum(faces),length(faces),c(:,tValues(i))));
   end

   % Plot curves
   h1(i) = plot(100*success/instances);
   h2(i) = plot(1:r,100*remboEmpr,'r--');

   set([h1(i),h2(i)],'LineWidth',2,'Color',cValues(i,:)');
   set(h1(i),'Marker',markers{i},'Markersize',7);
   set(h2(i),'Marker',markers{i},'Markersize',7);
end

hold off; box on; ylim([0,105]);
hlabel = xlabel('r');
hlabel = [hlabel ylabel('Recovery rate (%)')];
set(hlabel,'Fontsize',22);
set(gca,'Fontsize',18);
legend(h1,'s = 8','s = 9','s = 10','Location','SouthEast');

% Export figure to PDF file
if exportFlag
   ExportFigurePDF(prefix, sprintf('FigReMBo_%d.pdf',trials(t)));
end

