function success = GenerateTriangle(A,X0,vertices,normals)
% GENERATETRIANGLE   Tests L12 recovery at each grid point within the triangle
%
%    SUCCESS = GENERATETRIANGLE(A,X0,VERTICES,NORMALS). Given matrix A and X0
%    this scripts tests recoverability using L12 of from B = AX0W, where W is
%    a diagonal weighting matrix with weights depending on the location within
%    a triangle. The triangle has vertex positions given by VERTICES and
%    weights are determined by taking inner products with the NORMALS, relative
%    to the vertex position. The output is an array indicating success (1),
%    failure (0), or not a valid weight combination (NaN).
%    Used by TestTriangle.m, TestTriangle2.m, TestTriangle3.m.

%    Copyright 2009, Ewout van den Berg and Michael P. Friedlander
%    This file is part of the code accompanying the paper: Joint-sparse
%    recovery from multiple measurements, submitted April 2009.

% Create grid and initialize weight vector
xd = linspace(0,max(vertices(1,:)),100);
yd = linspace(0,max(vertices(2,:)),100);
w  = zeros(3,1);

% Initialize success matrix
success = ones(length(yd),length(xd)) * NaN;

for i=1:length(yd)
   for j=1:length(xd)
      pt = [xd(j);yd(i)]; % Get point in grid
      for k=1:3
         w(k) = 1 - normals(:,k)' * (pt - vertices(:,k));
      end
      if (any(w < 0) || any(w > 1))
         continue;
      else
         XW = X0 * diag(w);
         B  = A*XW;

         [X,info] = cvx_l12(A,B);
         if norm(X(:)-XW(:),inf) < 1e-5
            success(i,j) = 1;
         else
            success(i,j) = 0;
         end
      end
   end
end

