function [s1,s2] = TestTriangle(sparsity,exportFlag)
% TESTTRIANGLE   Generates two recovery triangles for fail/succeed pairs
%
%    [S1,S2] = TESTTRIANGLE(SPARSITY,EXPORTFLAG)  generates a standard 20x60
%    matrix A and two sparse vectors x that can and two that cannot be
%    recovered from b = Ax using L1 recovery. Recovery of a matrix X
%    consisting of three of the four vectors with different weights on each
%    column is then tested. The recovery results with relative weight
%    position indicated on an equiangular triangle are generated. When the
%    EXPORTFLAG parameters is set the plot will be exported to a PNG file.

%    Copyright 2009, Ewout van den Berg and Michael P. Friedlander
%    This file is part of the code accompanying the paper: Joint-sparse
%    recovery from multiple measurements, submitted April 2009.

% Check arguments
if nargin < 2, exportFlag = 0; end

% Load the standard 20x60 matrix A
[A,state] = GenerateMatrixA(20,60);
[m,n] = size(A);
randn('state',state); rand('state',0);

% Set up triangle coordinates
vertices = [0  1  cos(pi/3);
            0  0  sin(pi/3)];  % Vertices

% Set up normalized inner-product vectors
normals = [cos(pi/6) cos(5*pi/6) 0
           sin(pi/6) sin(5*pi/6) -1] / sin(pi/3);

% Construct filename
prefix   = mfilepath(mfilename('fullpath'));
filename =  sprintf('%sTestTriangle_s%d.mat',prefix,sparsity);

if ~exist(filename)
   % Find four vectors with same support; two vectors that can be
   % recovered using l1 and two that cannot.
   X = zeros(n,4);
   for i=1:100
      n0 = 0; n1 = 0;
      pr = randperm(n);
      X0 = zeros(n,100);
      X0(pr(1:sparsity),:) = randn(sparsity,100);
      B  = A*X0;

      for j=1:100
         [x,info] = cvx_bp(A,B(:,j));
         if norm(x-X0(:,j),inf) < 1e-5
            if n0 < 2
               X(:,1+n0) = X0(:,j);
               n0 = n0 + 1;
            end         
         else
            if n1 < 2
               X(:,3+n1) = X0(:,j);
               n1 = n1 + 1;
            end         
         end      

         if (n0 == 2) && (n1 == 2), break; end;
      end

      if (n0 == 2) && (n1 == 2), break; end;
   end

   % Try whole range of relative weights, s1,f1,f2
   s1 = GenerateTriangle(A,X(:,[1,3,4]),vertices,normals);
   save(filename,'X','s1');

   % Try whole range of relative weights, s1,s2,f2
   s2= GenerateTriangle(A,X(:,[1,2,4]),vertices,normals);
   save(filename,'X','s1','s2');
else
  load(filename);
end

% Swich to local directory
p = pwd; cd(prefix);

figure(1);
PlotTriangle(vertices,normals,s1,0.5,{'s_1','f_1','f_2'});
if exportFlag
   filename = sprintf('TestTriangle_s%da.png',sparsity);
   fprintf('Warning: Manual image post-processing required for %s! File export disabled.\n', filename);
%  cmd = sprintf('print -dpng %s',filename);
%  eval(cmd);
end

figure(2);
PlotTriangle(vertices,normals,s2,0.5,{'s_1','s_2','f_2'});
if exportFlag
   filename = sprintf('TestTriangle_s%db.png',sparsity);
   fprintf('Warning: Manual image post-processing required for %s! File export disabled.\n', filename);
%  cmd = sprintf('print -dpng %s',filename);
%  eval(cmd);
end

% Restore original directory
cd(p);

