function [s1,s2] = TestTriangle2(sparsity,exportFlag)
% TESTTRIANGLE2   Generates two recovery triangles for fail/succeed pairs
%
%    [S1,S2] = TESTTRIANGLE2(SPARSITY,EXPORTFLAG)  generates a standard 20x60
%    matrix A and four sparse vectors x that cannot be recovered from b = Ax
%    using L1 recovery. Recovery of a matrix X consisting of three of the four
%    vectors with different weights on each column is then tested. The
%    recovery results with relative weight position indicated on an equiangular
%    triangle are generated.  When the EXPORTFLAG parameters is set the plot
%    will be exported to a PNG file.

%    Copyright 2009, Ewout van den Berg and Michael P. Friedlander
%    This file is part of the code accompanying the paper: Joint-sparse
%    recovery from multiple measurements, submitted April 2009.

% Check arguments
if nargin < 2, exportFlag = 0; end

% Load the standard 20x60 matrix A
[A,state] = GenerateMatrixA(20,60);
[m,n] = size(A);
randn('state',state); rand('state',0);

% Set up triangle coordinates
vertices = [0  1  cos(pi/3);
            0  0  sin(pi/3)];  % Vertices

% Set up normalized inner-product vectors
normals = [cos(pi/6) cos(5*pi/6) 0
           sin(pi/6) sin(5*pi/6) -1] / sin(pi/3);

% Construct filename
prefix   = mfilepath(mfilename('fullpath'));
filename =  sprintf('%sTestTriangle2_s%d.mat',prefix,sparsity);

if ~exist(filename)
   % Find four vectors with same support that cannot be
   % recovered using l1
   X = zeros(n,4);
   for i=1:100 % Maximum number of supports to test
      n1 = 0;
      pr = randperm(n);
      X0 = zeros(n,100);
      X0(pr(1:sparsity),:) = randn(sparsity,100);
      B  = A*X0;

      for j=1:100 % Hopefully can find four vectors per 100 that fail
         [x,info] = cvx_bp(A,B(:,j));
         if norm(x-X0(:,j),inf) >= 1e-5
            X(:,1+n1) = X0(:,j);
            n1 = n1 + 1;
         end      

         if (n1 == 4), break; end;
      end

      if (n1 == 4), break; end;
   end

   % Try whole range of relative weights, f1,f2,f3
   s1 = GenerateTriangle(A,X(:,[1,2,3]),vertices,normals);
   save(filename,'X','s1');

   % Try whole range of relative weights, f1,f2,f4
   s2= GenerateTriangle(A,X(:,[1,2,4]),vertices,normals);
   save(filename,'X','s1','s2');
else
  load(filename);
end

% Swich to local directory
p = pwd; cd(prefix);

figure(1);
PlotTriangle(vertices,normals,s1,0.5,{'f_1','f_2','f_3'});
if exportFlag
   filename = sprintf('TestTriangle2_s%da.png',sparsity);
   fprintf('Warning: Manual image post-processing required for %s! File export disabled.\n', filename);
%  cmd = sprintf('print -dpng %s',filename);
%  eval(cmd);
end

figure(2);
PlotTriangle(vertices,normals,s2,0.5,{'f_1','f_2','f_4'});
if exportFlag
   filename = sprintf('TestTriangle2_s%db.png',sparsity);
   fprintf('Warning: Manual image post-processing required for %s! File export disabled.\n', filename);
%  cmd = sprintf('print -dpng %s',filename);
%  eval(cmd);
end

% Restore original directory
cd(p);

